@@ -172,7 +172,7 @@ impl<const LEN: usize, const REVERSE_STR: bool> Array<u8, LEN, REVERSE_STR> {
     pub fn random() -> Self {
         use rand::RngCore;
         let mut entropy = [0u8; LEN];
-        rand::thread_rng().fill_bytes(&mut entropy);
+        rand::rng().fill_bytes(&mut entropy);
         Array::from_inner(entropy)
     }
 
@@ -197,7 +197,19 @@ impl<const LEN: usize, const REVERSE_STR: bool> Array<u8, LEN, REVERSE_STR> {
     ///
     /// Panics if the slice length doesn't match `LEN` constant generic.
     #[inline]
+    #[deprecated(since = "4.9.0", note = "use `from_slice_checked` instead")]
     pub fn from_slice_unsafe(slice: impl AsRef<[u8]>) -> Self {
+        Self::from_slice_checked(slice)
+    }
+
+    /// Constructs a byte array from the slice. Expects the slice length
+    /// doesn't match `LEN` constant generic.
+    ///
+    /// # Safety
+    ///
+    /// Panics if the slice length doesn't match `LEN` constant generic.
+    #[inline]
+    pub fn from_slice_checked(slice: impl AsRef<[u8]>) -> Self {
         Self::copy_from_slice(slice).expect("slice length not matching type requirements")
     }
 
@@ -733,7 +745,20 @@ pub trait ByteArray<const LEN: usize>: Sized {
     /// # Safety
     ///
     /// Panics if the slice length doesn't match `LEN` constant generic.
-    fn from_slice_unsafe(slice: impl AsRef<[u8]>) -> Self;
+    #[deprecated(since = "4.9.0", note = "use from_slice_unsafe instead")]
+    fn from_slice_unsafe(slice: impl AsRef<[u8]>) -> Self {
+        Self::from_slice_checked(slice)
+    }
+
+    /// Constructs a byte array from the slice. Expects the slice length
+    /// doesn't match `LEN` constant generic.
+    ///
+    /// # Safety
+    ///
+    /// Panics if the slice length doesn't match `LEN` constant generic.
+    fn from_slice_checked(slice: impl AsRef<[u8]>) -> Self {
+        Self::from_slice(slice).expect("slice length not matching type requirements")
+    }
 
     /// Returns a byte array representation stored in the wrapped type.
     fn to_byte_array(&self) -> [u8; LEN];
@@ -751,10 +776,6 @@ where
         Array::try_from(slice.as_ref()).map(Self::from_inner)
     }
 
-    fn from_slice_unsafe(slice: impl AsRef<[u8]>) -> Self {
-        Self::from_slice(slice).expect("slice length not matching type requirements")
-    }
-
     fn to_byte_array(&self) -> [u8; LEN] {
         self.as_inner().into_inner()
     }
